searchData={"items":[{"type":"module","title":"VintageNetMobile","doc":"Use cellular modems with VintageNet\n\nThis module is not intended to be called directly but via calls to `VintageNet`. Here's a\ntypical example:\n\n```elixir\nVintageNet.configure(\n  \"ppp0\",\n  %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: VintageNetMobile.Modem.QuectelBG96,\n      service_providers: [%{apn: \"super\"}]\n    }\n  }\n)\n```\n\nThe `:modem` key should be set to your modem implementation. Cellular modems\ntend to be very similar. If `vintage_net_mobile` doesn't support your modem, see\nthe customizing section. It may just be a copy/paste away. See your modem\nmodule for modem-specific options. The following keys are supported by all modems:\n\n* `:service_providers` - This is a list of service provider information\n* `:chatscript_additions` - This is a string (technically iodata) for custom\n   modem initialization.\n\nThe `:service_providers` key should be set to information provided by each of\nyour service providers. It is common that this is a list of one item.\nCircumstances may require you to list more than one, though. Additionally, modem\nimplementations may require more or less information depending on their\nimplementation. (It's possible to hard-code the service provider in the modem\nimplementation. In that case, this key isn't used and should be set to an empty\nlist. This is useful when your cellular modem provides instructions that\nmagically work and the AT commands that they give are confusing.)\n\nInformation for each service provider is a map with some or all of the following\nfields:\n\n* `:apn` (required) - e.g., `\"access_point_name\"`\n* `:usage` (optional) - `:eps_bearer` (LTE) or `:pdp` (UMTS/GPRS)\n\nYour service provider should provide you with the information that you need to\nconnect. Often it is just an APN. The Gnome project provides a database of\n[service provider\ninformation](https://wiki.gnome.org/Projects/NetworkManager/MobileBroadband/ServiceProviders)\nthat may also be useful.\n\nHere's an example with a service provider list:\n\n```elixir\n  %{\n    type: VintageNetMobile,\n    modem: your_modem,\n    vintage_net_mobile: %{\n      service_providers: [\n        %{apn: \"wireless.twilio.com\"}\n      ],\n      chatscript_additions: \"OK AT\"\n    }\n  }\n```","ref":"VintageNetMobile.html"},{"type":"module","title":"Custom modems - VintageNetMobile","doc":"`VintageNetMobile` allows you add custom modem implementations if the built-in\nones don't work for you. See the `VintageNetMobile.Modem` behaviour.\n\nIn order to implement a modem, you will need:\n\n1. Instructions for connecting to the modem via your Linux. Sometimes this\n  involves `usb_modeswitch` or knowing which serial ports the modem exposes.\n2. Example chat scripts. These are lists of `AT` commands and their expected\n  responses for configuring the service provider and entering `PPP` mode.\n3. (Optional) Instructions for checking the signal strength when connected.\n\nOne strategy is to see if there's an existing modem that looks similar to yours\nand modify it.","ref":"VintageNetMobile.html#module-custom-modems"},{"type":"type","title":"VintageNetMobile.mobile_options/0","doc":"The `:vintage_net_mobile` option in the configuration map\n\nOnly the `:service_providers` key must be specified. Modems may\nadd keys of their own.","ref":"VintageNetMobile.html#t:mobile_options/0"},{"type":"type","title":"VintageNetMobile.rat/0","doc":"Radio Access Technology (RAT)\n\nThese define how to connect to the cellular network.","ref":"VintageNetMobile.html#t:rat/0"},{"type":"type","title":"VintageNetMobile.service_provider_info/0","doc":"Information about a service provider\n\n* `:apn` (required) - e.g., `\"access_point_name\"`\n* `:usage` (optional) - `:eps_bearer` (LTE) or `:pdp` (UMTS/GPRS)","ref":"VintageNetMobile.html#t:service_provider_info/0"},{"type":"module","title":"VintageNetMobile.ASUCalculator","doc":"Convert raw ASU values to friendlier units\n\nSee https://en.wikipedia.org/wiki/Mobile_phone_signal#ASU for\nmore information.\n\nThe following conversions are done:\n\n* dBm\n* Number of \"bars\" out of 4 bars","ref":"VintageNetMobile.ASUCalculator.html"},{"type":"function","title":"VintageNetMobile.ASUCalculator.from_gsm_asu/1","doc":"Compute signal level numbers from a GSM ASU\n\nThe `AT+CSQ` command should report ASU values in this format.","ref":"VintageNetMobile.ASUCalculator.html#from_gsm_asu/1"},{"type":"type","title":"VintageNetMobile.ASUCalculator.bars/0","doc":"Number of bars out of 4 to show in a UI","ref":"VintageNetMobile.ASUCalculator.html#t:bars/0"},{"type":"type","title":"VintageNetMobile.ASUCalculator.dbm/0","doc":"dBm","ref":"VintageNetMobile.ASUCalculator.html#t:dbm/0"},{"type":"type","title":"VintageNetMobile.ASUCalculator.gsm_asu/0","doc":"GSM ASU values\n\nASU values map to RSSI. 99 means unknown","ref":"VintageNetMobile.ASUCalculator.html#t:gsm_asu/0"},{"type":"type","title":"VintageNetMobile.ASUCalculator.lte_asu/0","doc":"LTE ASU values\n\nASU values map to RSRP\n\nhttps://arimas.com/78-rsrp-and-rsrq-measurement-in-lte/","ref":"VintageNetMobile.ASUCalculator.html#t:lte_asu/0"},{"type":"type","title":"VintageNetMobile.ASUCalculator.umts_asu/0","doc":"UMTS ASU values\n\nASU values map to RSCP","ref":"VintageNetMobile.ASUCalculator.html#t:umts_asu/0"},{"type":"module","title":"VintageNetMobile.CellMonitor","doc":"Monitor cell network information\n\nThis monitor queries the modem for cell network information and posts it to\nVintageNet properties.\n\nThe following properties are reported:\n\n| Property      | Values         | Description                   |\n| ------------- | -------------- | ----------------------------- |\n| `lac`         | `0-65533`      | The Location Area Code (lac) for the current cell |\n| `cid`         | `0-268435455`  | The Cell ID (cid) for the current cell |\n| `mcc`         | `0-999`        | Mobile Country Code for the network |\n| `mnc`         | `0-999`        | Mobile Network Code for the network |\n| `network`     | string         | The network operator's name |\n| `access_technology` | string   | The technology currently in use to connect to the network |\n| `band`        | string         | The frequency band in use |\n| `channel`     | integer        | An integer that indicates the channel that's in use |","ref":"VintageNetMobile.CellMonitor.html"},{"type":"function","title":"VintageNetMobile.CellMonitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"VintageNetMobile.CellMonitor.html#child_spec/1"},{"type":"function","title":"VintageNetMobile.CellMonitor.start_link/1","doc":"","ref":"VintageNetMobile.CellMonitor.html#start_link/1"},{"type":"module","title":"VintageNetMobile.ExChat","doc":"Send commands to your modem and get notifications\n\nThis module is used by the \"monitor\" modules for reporting modem and\nconnection status.\n\nIt can be handy to debug modems too. If you'd like to send commands and\nreceive notifications from the IEx prompt, here's what to do:\n\n```elixir\nrequire Logger\nRingLogger.attach\ntty_name = \"ttyUSB2\" # set to your AT command interface\nVintageNetMobile.ExChat.register(tty_name, \"+\", fn m -> Logger.debug(\"Got: \" <> inspect(m)) end)\nVintageNetMobile.ExChat.send(tty_name, \"AT+CSQ\")\n```\n\nTo reset the registrations, `VintageNet.deconfigure/2` and\n`VintageNet.configure/3` your modem.","ref":"VintageNetMobile.ExChat.html"},{"type":"function","title":"VintageNetMobile.ExChat.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"VintageNetMobile.ExChat.html#child_spec/1"},{"type":"function","title":"VintageNetMobile.ExChat.register/3","doc":"Register a callback function for reports","ref":"VintageNetMobile.ExChat.html#register/3"},{"type":"function","title":"VintageNetMobile.ExChat.send/3","doc":"Send a command to the modem\n\nOn success, this returns a list of the lines received back from the modem.","ref":"VintageNetMobile.ExChat.html#send/3"},{"type":"function","title":"VintageNetMobile.ExChat.send_best_effort/3","doc":"Helper for sending commands to the modem as best effort\n\nThis function always succeeds. Failed commands log errors, but that's it. This\nis useful for monitoring operations where intermittent failures should be logged,\nbut really aren't worth dealing with.","ref":"VintageNetMobile.ExChat.html#send_best_effort/3"},{"type":"function","title":"VintageNetMobile.ExChat.start_link/1","doc":"","ref":"VintageNetMobile.ExChat.html#start_link/1"},{"type":"type","title":"VintageNetMobile.ExChat.opt/0","doc":"The options for the ATCommand server are:\n\n* `:speed` - the speed of the serial connection\n* `:tty` - the tty name for sending AT commands\n* `:uart` - use an alternative UART-provider (for testing)\n* `:uart_opts` - additional options to pass to UART.open","ref":"VintageNetMobile.ExChat.html#t:opt/0"},{"type":"behaviour","title":"VintageNetMobile.Modem","doc":"A behaviour for modem implementations","ref":"VintageNetMobile.Modem.html"},{"type":"callback","title":"VintageNetMobile.Modem.add_raw_config/3","doc":"Update the raw configuration for the modem\n\nThe incoming raw configuration (first parameter) will have an initial generic\nconfiguration that should be common to most modems. The second parameter is\nthe normalized VintageNet configuration and the final options are the ones\nfrom VintageNet for determining file paths, etc.\n\nConfiguration errors raise exceptions, but it is good practice to catch the\nerrors in `normalize/1`.","ref":"VintageNetMobile.Modem.html#c:add_raw_config/3"},{"type":"callback","title":"VintageNetMobile.Modem.normalize/1","doc":"Normalize a modem configuration\n\nModem implementations use this to update the `:modem_opts` key to a canonical\nrepresentation. This could be adding default fields, migrating old options,\nor deriving parameters to that they need not be computed again.\n\nConfiguration errors raise exceptions.","ref":"VintageNetMobile.Modem.html#c:normalize/1"},{"type":"module","title":"VintageNetMobile.Modem.Automatic","doc":"Modem for automatic detection and configuration of USB-based modems\n\nThis is useful for when you need to support different types of modems and you\ncannot provide a static configuration for one particular modem.","ref":"VintageNetMobile.Modem.Automatic.html"},{"type":"module","title":"VintageNetMobile.Modem.HuaweiE3372","doc":"Huawei E3372 support\n\nBEWARE:\nThis modem will need a mode switch before you can connect, this can be done\nusing VintageNet's power management functionality like this:\n\n```elixir\n  config :vintage_net, power_managers: [{VintageNetMobile.Modem.HuaweiE3372.Modeswitch, ifname: \"ppp0\"}]\n```\n\nWith this in your configuration you can now do the following to connect with\nthe modem:\n\n```elixir\n  VintageNet.configure(\"ppp0\", %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: VintageNetMobile.Modem.HuaweiE3372,\n      service_providers: [%{apn: \"some apn\"}]\n    }\n  })\n```\n\nBEWARE Currently none of the Signal, Cell and Modem monitors are working.","ref":"VintageNetMobile.Modem.HuaweiE3372.html"},{"type":"function","title":"VintageNetMobile.Modem.HuaweiE3372.chatscript/1","doc":"","ref":"VintageNetMobile.Modem.HuaweiE3372.html#chatscript/1"},{"type":"module","title":"VintageNetMobile.Modem.HuaweiE3372.Modeswitch","doc":"VintageNetMobile PowerManager to handle the HuaweiE3372 modem","ref":"VintageNetMobile.Modem.HuaweiE3372.Modeswitch.html"},{"type":"module","title":"VintageNetMobile.Modem.QuectelBG96","doc":"Quectel BG96 support\n\nThe Quectel BG96 is an LTE Cat M1/Cat NB1/EGPRS module. Here's an example\nconfiguration:\n\n```elixir\nVintageNet.configure(\n  \"ppp0\",\n  %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: VintageNetMobile.Modem.QuectelBG96,\n      service_providers: [%{apn: \"super\"}]\n    }\n  }\n)\n```\n\nOptions:\n\n* `:modem` - `VintageNetMobile.Modem.QuectelBG96`\n* `:service_providers` - A list of service provider information (only `:apn`\n  providers are supported)\n* `:at_tty` - A tty for sending AT commands on. This defaults to `\"ttyUSB2\"`\n  which works unless other USB serial devices cause Linux to set it to\n  something different.\n* `:ppp_tty` - A tty for the PPP connection. This defaults to `\"ttyUSB2\"`\n  which works unless other USB serial devices cause Linux to set it to\n  something different.\n* `:scan` - Set this to the order that radio access technologies should be\n  attempted when trying to connect. For example, `[:lte_cat_m1, :gsm]`\n  would prevent the modem from trying LTE Cat NB1 and potentially save some\n  time if you're guaranteed to not have Cat NB1 service.\n\nIf multiple service providers are configured, this implementation only\nattempts to connect to the first one.\n\nExample of supported properties:\n\n```elixir\niex> VintageNet.get_by_prefix([\"interface\", \"ppp0\"])\n[\n  {[\"interface\", \"ppp0\", \"addresses\"],\n  [\n    %{\n      address: {10, 64, 64, 64},\n      family: :inet,\n      netmask: {255, 255, 255, 255},\n      prefix_length: 32,\n      scope: :universe\n    }\n  ]},\n  {[\"interface\", \"ppp0\", \"connection\"], :internet},\n  {[\"interface\", \"ppp0\", \"lower_up\"], true},\n  {[\"interface\", \"ppp0\", \"mobile\", \"access_technology\"], \"CAT-M1\"},\n  {[\"interface\", \"ppp0\", \"mobile\", \"band\"], \"LTE BAND 12\"},\n  {[\"interface\", \"ppp0\", \"mobile\", \"channel\"], 5110},\n  {[\"interface\", \"ppp0\", \"mobile\", \"cid\"], 18677159},\n  {[\"interface\", \"ppp0\", \"mobile\", \"lac\"], 4319},\n  {[\"interface\", \"ppp0\", \"mobile\", \"mcc\"], 310},\n  {[\"interface\", \"ppp0\", \"mobile\", \"mnc\"], 410},\n  {[\"interface\", \"ppp0\", \"mobile\", \"network\"], \"AT&T\"},\n  {[\"interface\", \"ppp0\", \"mobile\", \"signal_4bars\"], 4},\n  {[\"interface\", \"ppp0\", \"mobile\", \"signal_asu\"], 25},\n  {[\"interface\", \"ppp0\", \"mobile\", \"signal_dbm\"], -63},\n  {[\"interface\", \"ppp0\", \"present\"], true},\n  {[\"interface\", \"ppp0\", \"state\"], :configured},\n  {[\"interface\", \"ppp0\", \"type\"], VintageNetMobile}\n]\n```","ref":"VintageNetMobile.Modem.QuectelBG96.html"},{"type":"module","title":"Required Linux kernel options - VintageNetMobile.Modem.QuectelBG96","doc":"* CONFIG_USB_SERIAL=m\n* CONFIG_USB_SERIAL_WWAN=m\n* CONFIG_USB_SERIAL_OPTION=m\n* CONFIG_USB_WDM=m\n* CONFIG_USB_NET_QMI_WWAN=m","ref":"VintageNetMobile.Modem.QuectelBG96.html#module-required-linux-kernel-options"},{"type":"module","title":"VintageNetMobile.Modem.QuectelEC25","doc":"Quectel EC25 support\n\nThe Quectel EC25 is a series of LTE Cat 4 modules. Here's an example\nconfiguration:\n\n```elixir\nVintageNet.configure(\n  \"ppp0\",\n  %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: VintageNetMobile.Modem.QuectelEC25,\n      service_providers: [%{apn: \"wireless.twilio.com\"}]\n    }\n  }\n)\n```\n\nOptions:\n\n* `:modem` - `VintageNetMobile.Modem.QuectelEC25`\n* `:service_providers` - A list of service provider information (only `:apn`\n  providers are supported)\n* `:at_tty` - A tty for sending AT commands on. This defaults to `\"ttyUSB2\"`\n  which works unless other USB serial devices cause Linux to set it to\n  something different.\n* `:ppp_tty` - A tty for the PPP connection. This defaults to `\"ttyUSB2\"`\n  which works unless other USB serial devices cause Linux to set it to\n  something different.\n\nIf multiple service providers are configured, this implementation only\nattempts to connect to the first one.\n\nExample of supported properties:\n\n```elixir\niex> VintageNet.get_by_prefix([\"interface\", \"ppp0\"])\n[\n  {[\"interface\", \"ppp0\", \"addresses\"],\n  [\n    %{\n      address: {10, 64, 64, 64},\n      family: :inet,\n      netmask: {255, 255, 255, 255},\n      prefix_length: 32,\n      scope: :universe\n    }\n  ]},\n  {[\"interface\", \"ppp0\", \"connection\"], :internet},\n  {[\"interface\", \"ppp0\", \"lower_up\"], true},\n  {[\"interface\", \"ppp0\", \"mobile\", \"access_technology\"], \"FDD LTE\"},\n  {[\"interface\", \"ppp0\", \"mobile\", \"band\"], \"LTE BAND 4\"},\n  {[\"interface\", \"ppp0\", \"mobile\", \"channel\"], 2300},\n  {[\"interface\", \"ppp0\", \"mobile\", \"cid\"], 11303407},\n  {[\"interface\", \"ppp0\", \"mobile\", \"lac\"], 10234},\n  {[\"interface\", \"ppp0\", \"mobile\", \"mcc\"], 360},\n  {[\"interface\", \"ppp0\", \"mobile\", \"mnc\"], 200},\n  {[\"interface\", \"ppp0\", \"mobile\", \"network\"], \"Twilio\"},\n  {[\"interface\", \"ppp0\", \"mobile\", \"signal_asu\"], 21},\n  {[\"interface\", \"ppp0\", \"mobile\", \"signal_4bars\"], 4},\n  {[\"interface\", \"ppp0\", \"mobile\", \"signal_dbm\"], -71},\n  {[\"interface\", \"ppp0\", \"present\"], true},\n  {[\"interface\", \"ppp0\", \"state\"], :configured},\n  {[\"interface\", \"ppp0\", \"type\"], VintageNetMobile}\n]\n```","ref":"VintageNetMobile.Modem.QuectelEC25.html"},{"type":"module","title":"Required Linux kernel options - VintageNetMobile.Modem.QuectelEC25","doc":"* CONFIG_USB_SERIAL=m\n* CONFIG_USB_SERIAL_WWAN=m\n* CONFIG_USB_SERIAL_OPTION=m\n* CONFIG_USB_WDM=m\n* CONFIG_USB_NET_QMI_WWAN=m","ref":"VintageNetMobile.Modem.QuectelEC25.html#module-required-linux-kernel-options"},{"type":"module","title":"VintageNetMobile.Modem.SierraHL8548","doc":"Sierra Wireless HL8548 modem\n\nhttps://source.sierrawireless.com/resources/airprime/hardware_specs_user_guides/airprime_hl8548_and_hl8548-g_product_technical_specification/\n\nThe Sierra Wireless HL8548 is an industrial grade Embedded Wireless Module\nthat provides voice and data connectivity on GPRS, EDGE, WCDMA, HSDPA and\nHSUPA networks.\n\nHere's an example configuration:\n\n```elixir\nVintageNet.configure(\n  \"ppp0\",\n  %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: VintageNetMobile.Modem.SierraHL8548,\n      service_providers: [%{apn: \"BROADBAND\"}]\n    }\n  }\n)\n```","ref":"VintageNetMobile.Modem.SierraHL8548.html"},{"type":"module","title":"VintageNetMobile.Modem.TelitLE910","doc":"Telit LE910 support\n\n```elixir\nVintageNet.configure(\n  \"ppp0\",\n  %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: VintageNetMobile.Modem.TelitLE910,\n      service_providers: [%{apn: \"wireless.twilio.com\"}]\n    }\n  }\n)\n```\n\nIf multiple service providers are configured, this implementation only\nattempts to connect to the first one.\n\nExample of supported properties\n\n```elixir\niex> VintageNet.get_by_prefix [\"interface\", \"ppp0\"]\n[\n{[\"interface\", \"ppp0\", \"addresses\"],\n [\n   %{\n     address: {100, 79, 181, 147},\n     family: :inet,\n     netmask: {255, 255, 255, 255},\n     prefix_length: 32,\n     scope: :universe\n   }\n ]},\n{[\"interface\", \"ppp0\", \"config\"],\n %{\n   type: VintageNetMobile,\n   vintage_net_mobile: %{\n     modem: VintageNetMobile.Modem.TelitLE910,\n     service_providers: [%{apn: \"super\"}, %{apn: \"wireless.twilio.com\"}]\n   }\n }},\n{[\"interface\", \"ppp0\", \"connection\"], :internet},\n{[\"interface\", \"ppp0\", \"hw_path\"], \"/devices/virtual\"},\n{[\"interface\", \"ppp0\", \"lower_up\"], true},\n{[\"interface\", \"ppp0\", \"mobile\", \"cid\"], 123098825},\n{[\"interface\", \"ppp0\", \"mobile\", \"lac\"], 32773},\n{[\"interface\", \"ppp0\", \"mobile\", \"signal_4bars\"], 3},\n{[\"interface\", \"ppp0\", \"mobile\", \"signal_asu\"], 19},\n{[\"interface\", \"ppp0\", \"mobile\", \"signal_dbm\"], -75},\n{[\"interface\", \"ppp0\", \"present\"], true},\n{[\"interface\", \"ppp0\", \"state\"], :configured},\n{[\"interface\", \"ppp0\", \"type\"], VintageNetMobile}\n]\n```","ref":"VintageNetMobile.Modem.TelitLE910.html"},{"type":"module","title":"VintageNetMobile.Modem.UbloxTOBYL2","doc":"# u-blox TOBY-L2 support\n\nThe u-blox TOBY-L2 is a series of LTE Cat 4 modules with HSPA+ and/or 2G\nfallback. Here's an example configuration:\n\n```elixir\nVintageNet.configure(\n  \"ppp0\",\n  %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: VintageNetMobile.Modem.UbloxTOBYL2,\n      service_providers: [\n        %{apn: \"lte-apn\", usage: :eps_bearer},\n        %{apn: \"old-apn\", usage: :pdp}\n      ]\n    }\n  }\n)\n```\n\nThis implementation currently requires APNs to be annotated for whether\nthey are to be used on LTE (`:eps_bearer`) or on UMTS/GPRS (`:pdp`).","ref":"VintageNetMobile.Modem.UbloxTOBYL2.html"},{"type":"module","title":"Required Linux kernel options - VintageNetMobile.Modem.UbloxTOBYL2","doc":"* CONFIG_USB_SERIAL=m\n* CONFIG_USB_SERIAL_WWAN=m\n* CONFIG_USB_SERIAL_OPTION=m","ref":"VintageNetMobile.Modem.UbloxTOBYL2.html#module-required-linux-kernel-options"},{"type":"module","title":"Required modem preparation - VintageNetMobile.Modem.UbloxTOBYL2","doc":"The Toby L2 is a composite USB device that can be configured to expose\nvarious different interfaces. By default, it has one CDC ACM interface. This\nimplementation requires two, so you have to send it the following over a\ntty interface (via `Circuits.UART` or externally):\n\n```\nAT+UUSBCONF=2\n```\n\nThat command is saved NVRAM and only needs to be sent once.  See section\n\"19.17 USB profiles configuration +UUSBCONF\" in the [u-blox AT commands\nmanual](https://www.u-blox.com/en/docs/UBX-13002752)","ref":"VintageNetMobile.Modem.UbloxTOBYL2.html#module-required-modem-preparation"},{"type":"module","title":"VintageNetMobile.ModemInfo","doc":"Query the modem for device and SIM information\n\nThis monitor queries the modem for information about itself and its SIM and\nposts it to VintageNet properties.\n\nThe following properties are reported:\n\n| Property      | Values         | Description                   |\n| ------------- | -------------- | ----------------------------- |\n| `iccid`       | string         | The Integrated Circuit Card Identifier (ICCID) |\n| `imsi`        | string         | The International Mobile Subscriber Identity (IMSI) |","ref":"VintageNetMobile.ModemInfo.html"},{"type":"function","title":"VintageNetMobile.ModemInfo.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"VintageNetMobile.ModemInfo.html#child_spec/1"},{"type":"function","title":"VintageNetMobile.ModemInfo.start_link/1","doc":"","ref":"VintageNetMobile.ModemInfo.html#start_link/1"},{"type":"module","title":"VintageNetMobile.SignalMonitor","doc":"Monitor the cell signal levels\n\nThis monitor queries the modem for cell signal level information and posts it to\nVintageNet properties.\n\nThe following properties are reported:\n\n| Property       | Values       | Description                   |\n| -------------- | ------------ | ----------------------------- |\n| `signal_asu`   | `0-31,99`    | This is the raw Arbitrary Strength Unit (ASU) reported. It's interpretation depends on the modem and possibly the connection technology. |\n| `signal_4bars` | `0-4`        | The signal level in \"bars\" for presentation to a user. |\n| `signal_dbm`   | `-144 - -44` | The signal level in dBm. Interpretation depends on the connection technology. |","ref":"VintageNetMobile.SignalMonitor.html"},{"type":"function","title":"VintageNetMobile.SignalMonitor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"VintageNetMobile.SignalMonitor.html#child_spec/1"},{"type":"function","title":"VintageNetMobile.SignalMonitor.start_link/1","doc":"","ref":"VintageNetMobile.SignalMonitor.html#start_link/1"},{"type":"type","title":"VintageNetMobile.SignalMonitor.opt/0","doc":"The options for the monitor are:\n\n* `:signal_check_interval` - the number of milliseconds to wait before asking\n  the modem for the signal quality (default 5 seconds)\n* `:ifname` - the interface name the mobile connection is using\n* `:tty` - the tty name that is used to send AT commands","ref":"VintageNetMobile.SignalMonitor.html#t:opt/0"},{"type":"extras","title":"VintageNetMobile","doc":"# VintageNetMobile\n\n[![Hex version](https://img.shields.io/hexpm/v/vintage_net_mobile.svg \"Hex version\")](https://hex.pm/packages/vintage_net_mobile)\n[![API docs](https://img.shields.io/hexpm/v/vintage_net_mobile.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/vintage_net_mobile/VintageNetMobile.html)\n[![CircleCI](https://circleci.com/gh/nerves-networking/vintage_net_mobile.svg?style=svg)](https://circleci.com/gh/nerves-networking/vintage_net_mobile)\n\nThis library provides a `VintageNet` technology for using cellular modems.\nCurrently, it supports the following modems:\n\n* Quectel BG96 - [`VintageNetMobile.Modem.QuectelBG96`](https://www.quectel.com/product/bg96.htm)\n* Quectel EC25 - [`VintageNetMobile.Modem.QuectelEC25`](https://www.quectel.com/product/ec25.htm)\n* u-blox TOBY L2 - [`VintageNetMobile.Modem.UbloxTOBYL2`](https://www.u-blox.com/en/product/toby-l2-series)\n* Sierra Wireless HL8548 - [`VintageNetMobile.Modem.SierraHL8548`](https://source.sierrawireless.com/resources/airprime/hardware_specs_user_guides/airprime_hl8548_and_hl8548-g_product_technical_specification/)\n* Huawei E3372 - [`VintageNetMobile.Modem.HuaweiE3372`](https://consumer.huawei.com/en/routers/e3372/)\n* [ZTE MF833V] - does not need mobile driver, works with `VintageNetEthernet` when modem is configured to auto-connect\n\nSee the \"Custom Modems\" section for adding new modules.\n\nTo use this library, first add it to your project's dependency list:\n\n```elixir\ndef deps do\n  [\n    {:vintage_net_mobile, \"~> 0.11.1\"}\n  ]\nend\n```\n\nYou will then need to configure `VintageNet`. All cellular modems currently show\nup on \"ppp0\", so configurations look like this:\n\n```elixir\nVintageNet.configure(\"ppp0\", %{\n      type: VintageNetMobile,\n      vintage_net_mobile: %{\n        modem: your_modem,\n        service_providers: your_service_providers\n      }\n    })\n```\n\nThe `:modem` key should be set to your modem implementation. Cellular modems\ntend to be very similar. If `vintage_net_mobile` doesn't support your modem, see\nthe customizing section. It may just be a copy/paste away.\n\nThe `:service_providers` key should be set to information provided by each of\nyour service providers. It is common that this is a list of one item.\nCircumstances may require you to list more than one, though. Additionally, modem\nimplementations may require more information. (It's also possible to hard-code\nthe service provider in the modem implementation as a hack. In that case, this\nkey isn't used and should be set to an empty list. This is useful when your\ncellular modem provides instructions that magically work and the AT commands\nthat they give are confusing.)\n\nInformation for each service provider is a map with some or all of the following\nfields:\n\n* `:apn` (required) - e.g., `\"access_point_name\"`\n* `:usage` (optional) - `:eps_bearer` (LTE) or `:pdp` (UMTS/GPRS)\n\nYour service provider should provide you with the information that you need to\nconnect. Often it is just an APN. The Gnome project provides a database of\n[service provider\ninformation](https://wiki.gnome.org/Projects/NetworkManager/MobileBroadband/ServiceProviders)\nthat may also be useful.\n\nHere's an example with a service provider list:\n\n```elixir\n  %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: your_modem,\n      service_providers: [\n        %{apn: \"wireless.twilio.com\"}\n      ]\n    }\n  }\n```","ref":"readme.html"},{"type":"extras","title":"Automatic modem detection - VintageNetMobile","doc":"If it is not known ahead of time what modem will be installed, the\n`VintageNetMobile.Modem.Automatic` implementation can detect and configure it\nfor you. It works by waiting for the system to report a USB device with a known\nvendor and product ID. Once one is found, it calls `VintageNet.configure/3` to\nchange the configuration from using the `Automatic` modem to the actual modem\nimplementation. It tells `VintageNet.configure/3` to not persist the\nconfiguration so that the detection process runs again on the next boot.\n\nHere's an example:\n\n```elixir\n  %{\n    type: VintageNetMobile,\n    vintage_net_mobile: %{\n      modem: VintageNetMobile.Modem.Automatic,\n      service_providers: [\n        %{apn: \"wireless.twilio.com\"}\n      ]\n    }\n  }\n```\n\nSee [VintageNetMobile.Modem.Automatic.Discovery](lib/vintage_net_mobile/modem/automatic/discovery.ex)\nfor a list of modems that can be detected.\n\nTo check if your modem has been detected correctly you can run\n`VintageNet.info()` and check the output configuration's `:modem` field:\n\n```elixir\niex> VintageNet.info()\nInterface ppp0\n  Type: VintageNetMobile\n  Power: Starting up/on (248378 ms left)\n  Present: true\n  State: :configured (0:01:13)\n  Connection: :internet (21.8 s)\n  Addresses: 111.11.111.111/32\n  Configuration:\n    %{\n      type: VintageNetMobile,\n      vintage_net_mobile: %{\n        modem: VintageNetMobile.Modem.TelitLE910,\n        service_providers: [%{apn: \"thebestapn\"}]\n      }\n    }\n\n```","ref":"readme.html#automatic-modem-detection"},{"type":"extras","title":"VintageNet Properties - VintageNetMobile","doc":"In addition to the common `vintage_net` properties for all interface types, this\ntechnology reports one or more of the following:\n\n| Property      | Values         | Description                   |\n| ------------- | -------------- | ----------------------------- |\n| `signal_asu`  | `0-31,99`      | Reported Arbitrary Strength Unit (ASU) |\n| `signal_4bars` | `0-4`         | The signal level in \"bars\"    |\n| `signal_dbm`  | `-144 - -44`   | The signal level in dBm. Interpretation depends on the connection technology. |\n| `signal_rssi` | `0-31` or `99` | An integer between 0-31 or 99 |\n| `lac`         | `0-65533`      | The Location Area Code (lac) for the current cell |\n| `cid`         | `0-268435455`  | The Cell ID (cid) for the current cell |\n| `mcc`         | `0-999`        | Mobile Country Code for the network |\n| `mnc`         | `0-999`        | Mobile Network Code for the network |\n| `network`     | string         | The network operator's name |\n| `access_technology` | string   | The technology currently in use to connect to the network |\n| `band`        | string         | The frequency band in use |\n| `channel`     | integer        | An integer that indicates the channel that's in use |\n| `iccid`       | string         | The Integrated Circuit Card Identifier (ICCID) |\n| `imsi`        | string         | The International Mobile Subscriber Identity (IMSI) |\n\nPlease check your modem implementation for which properties it supports or run\n`VintageNet.get_by_prefix([\"interface\", \"ppp0\"])` and see what happens.","ref":"readme.html#vintagenet-properties"},{"type":"extras","title":"Custom modems - VintageNetMobile","doc":"`VintageNetMobile` allows you add custom modem implementations if the built-in\nones don't work for you. See the `VintageNetMobile.Modem` behaviour.\n\nIn order to implement a modem, you will need:\n\n1. Instructions for connecting to the modem via your Linux. Sometimes this\n   involves `usb_modeswitch` or knowing which serial ports the modem exposes.\n2. Example chat scripts. These are lists of `AT` commands and their expected\n   responses for configuring the service provider and entering `PPP` mode.\n3. (Optional) Instructions for checking the signal strength when connected.\n\nOne strategy is to see if there's an existing modem that looks similar to yours\nand modify it.","ref":"readme.html#custom-modems"},{"type":"extras","title":"Serial AT command debugging - VintageNetMobile","doc":"When porting `vintage_net_mobile` to a new cell modem, it can be useful to\nexperiment with the modem directly. To do this, add a dependency to\n[elixircom](https://github.com/mattludwigs/elixircom), rebuild, and then on the\ndevice, you can do things like this:\n\n```elixir\niex> Elixircom.run(\"/dev/ttyUSB2\", speed: 115200)\n```\n\nWill allow you to run AT commands. To test everything is okay:\n\n```elixir\niex> Elixircom.run(\"/dev/ttyUSB2\", speed: 115200)\n# type at and press enter\n\nOK\n```\n\nYour modem should supply a complete list of AT commands. The following may be\nuseful:\n\n| Command   | Description                                      |\n| --------- | ------------------------------------------------ |\n| at+csq    | Signal Strength                                  |\n| at+csq=?  | Query supported signal strength format           |\n| at+cfun?  | Level of functionality                           |\n| at+cfun=? | Query supported functionality levels             |\n| at+creg?  | Check if the modem has registered to a provider. |\n| at+cgreg? | Same as above for some modems                    |\n| at+qccid  | Query to obtain the Integrated Circuit Card Identifier             |\n| at+cimi   | Query to obtain the International Mobile Subscriber Identity             |","ref":"readme.html#serial-at-command-debugging"},{"type":"extras","title":"System requirements - VintageNetMobile","doc":"These requirements are believed to be the minimum needed to be added to the\nofficial Nerves systems.\n\n#","ref":"readme.html#system-requirements"},{"type":"extras","title":"Linux kernel - VintageNetMobile","doc":"Enable PPP and drivers for your modem:\n\n```text\nCONFIG_PPP=m\nCONFIG_PPP_BSDCOMP=m\nCONFIG_PPP_DEFLATE=m\nCONFIG_PPP_FILTER=y\nCONFIG_PPP_MPPE=m\nCONFIG_PPP_MULTILINK=y\nCONFIG_PPP_ASYNC=m\nCONFIG_PPP_SYNC_TTY=m\nCONFIG_USB_NET_CDC_NCM=m\nCONFIG_USB_NET_HUAWEI_CDC_NCM=m\nCONFIG_USB_NET_QMI_WWAN=m\nCONFIG_USB_SERIAL_OPTION=m\n```\n\n#","ref":"readme.html#linux-kernel"},{"type":"extras","title":"Buildroot (nerves_defconfig) - VintageNetMobile","doc":"Both `pppd` and `usb_modeswitch` are needed in the `nerves_defconfig`:\n\n```text\nBR2_PACKAGE_USB_MODESWITCH=y\nBR2_PACKAGE_PPPD=y\nBR2_PACKAGE_PPPD_FILTER=y\n```\n\n#","ref":"readme.html#buildroot-nerves_defconfig"},{"type":"extras","title":"Busybox - VintageNetMobile","doc":"Add the following to your `nerves_defconfig`:\n\n```text\nBR2_PACKAGE_BUSYBOX_CONFIG_FRAGMENT_FILES=\"${NERVES_DEFCONFIG_DIR}/busybox.fragment\"\n```\n\nand then create `busybox.fragment` with the following:\n\n```text\nCONFIG_MKNOD=y\nCONFIG_WC=y\n```","ref":"readme.html#busybox"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [v0.11.5] - 2024-02-02\n\n#","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"* Create `/var/run/pppd/lock` directory if it doesn't exist to avoid some\n  versions of `pppd` exiting. Thanks to @ringlej for the fix.\n\n## [v0.11.4] - 2023-06-10\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Fix deprecation warnings on Elixir 1.15\n\n## [v0.11.3] - 2023-01-23\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Support `:vintage_net` `v0.13.0` as well.\n\n## [v0.11.2] - 2023-01-16\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* Relax `muontrap` dependency requirement\n\n## [v0.11.1] - 2022-05-02\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"* `:vintage_net` `v0.12.0` or later is required\n\n## [v0.11.0] - 2022-02-25\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"* Support for the Telit LE910 modem (see `VintageNetMobile.Modem.TelitLE910`)\n* Support modem implementation selection at runtime. See\n  `VintageNetMobile.Modem.Automatic` for more details.\n\n## [v0.10.4] - 2022-02-16\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"* Fixed dropped `pppd` notifications to Elixir when using Nerves systems with\n  `glibc v2.33` and later. This affects Nerves toolchains with version numbers\n  `v1.4.2` and later.","ref":"changelog.html#fixed"},{"type":"extras","title":"v0.10.3 - Changelog","doc":"* Changes\n  * Allow `muontrap v1.0.0` to be used","ref":"changelog.html#v0-10-3"},{"type":"extras","title":"v0.10.2 - Changelog","doc":"* Changes\n  * Support `vintage_net v0.11.x` as well.","ref":"changelog.html#v0-10-2"},{"type":"extras","title":"v0.10.1 - Changelog","doc":"* Bug fixes\n  * `vintage_net v0.10.4` had a fix to route setup to remove a DHCP renewal\n    hiccup and a routing API change that only affected this project. This\n    updates to the new API to remove a deprecation warning. That also means that\n    at least `vintage_net v0.10.4` is required now and the deps force this.","ref":"changelog.html#v0-10-1"},{"type":"extras","title":"v0.10.0 - Changelog","doc":"This release contains no code changes. It only updates the `vintage_net`\ndependency to allow `vintage_net v0.10.0` to be used.","ref":"changelog.html#v0-10-0"},{"type":"extras","title":"v0.9.2 - Changelog","doc":"* New features\n  * Huawei E3372 support - Thanks to Hans Pagh for contributing his\n    implementation.\n\n* Bug fixes\n  * Handle more types of CREG responses. This should reduce warnings from the\n    CellMonitor code","ref":"changelog.html#v0-9-2"},{"type":"extras","title":"v0.9.1 - Changelog","doc":"* New features\n  * Support non-default tty paths for Quectel modems","ref":"changelog.html#v0-9-1"},{"type":"extras","title":"v0.9.0 - Changelog","doc":"* New features\n  * Add initial support for using the `VintageNet.PowerManager`to manage the\n    power to cellular modems. This allows `VintageNet` to power on and off a\n    modem as needed and if it becomes unresponsive. To use this, you will need\n    to provide an implementation of `VintageNet.PowerManager` that can control\n    the GPIO (or whatever) connections that enable power and can send\n    appropriate UART commands to power off. This only has been tested with\n    Quectel BG96 and EC25 modems, but should be applicable to all modems.\n  * Synchronize with vintage_net v0.9.0's networking program path API update","ref":"changelog.html#v0-9-0"},{"type":"extras","title":"v0.8.0 - Changelog","doc":"(Skipping version numbers to make the version match `vintage_net` for ease of\nremembering which versions are compatible.)\n\n* New features\n  * Add `:chatscript_additions` option to the modem configuration to support\n    arbitrary chatscript lines so that application-specific customizations don't\n    require you to make a custom modem. Of course, if you have an option of\n    general interest, please continue to make PRs.\n  * Support vintage_net v0.8.0's `required_ifnames` API update. This cleans up\n    some modem detection for non-usb_modswitch modems. If you have a fork of\n    this project, you'll need to update it. See commit 06456c3bc/PR #66 for how\n    the supported modems were changed.\n\n* Bug fixes\n  * Cleaned up handling of PPP disconnections. Amazingly, OTP supervision could\n    recover some of this, but the logs were really ugly and more work was done\n    than needed.","ref":"changelog.html#v0-8-0"},{"type":"extras","title":"v0.2.3 - Changelog","doc":"* Updates\n  * Allow `muontrap` v0.6.0 to be used since the breaking change doesn't affect\n    `vintage_net_mobile`\n  * Force `vintage_net` v0.7.9 or later to pull in PPP IP address fix","ref":"changelog.html#v0-2-3"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"* New features\n  * Added a \"monitor\" for reporting a SIM card's ICCID and IMSI. These are\n    useful for debugging issues with service providers. Currently this is\n    only available on the BG96, but can easily be added to other modems as\n    testing permits.","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"This release has improvements and bug fixes throughout, but primarily for the\nQuectel EC25 (LTE Cat 4 modem) and Quectel BG96 (LTE Cat M1/NB1 modem)\n\n* New features\n  * Network connection stats for the EC25 and BG96 modems. This lets you see how\n    the modem connected (GSM, UMTS, LTE, etc) and to which cell tower (cell id,\n    lac, mcc, mnc). This is useful for debug and geolocation.\n  * Improved signal strength reporting. The reports are now in ASU (arbitrary\n    strength units), dBm, and bars. Bars ranges from 0 bars (no connection) to 4\n    bars (strong signal) similar to a cell phone","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"This release has significant changes to the configuration API and\n`VintageNetMobile.Modem` behaviour. No migration from the old version is\nsupported. We don't expect to majorly change the API in future releases. Updates\nwill be more incremental. The plan is to add configuration migrations so that\ndevices in the field can continue to work between `vintage_net_mobile` updates.\n\nTo upgrade, find the module documentation for your modem. There will be a\nconfiguration example that should look familiar.","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.2 - Changelog","doc":"* Bug fix\n  * Prevent `VintageNet` from trying to run `ppp` before a modem is ready.","ref":"changelog.html#v0-1-2"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* Bug fixes\n  * Fix a timing issue when `VintageNet` would try to call a `VintageNetMobile`\n    process before it was started","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial `vintage_net_mobile` release.\n\n[v0.11.5]: https://github.com/nerves-networking/vintage_net_mobile/compare/v0.11.4...v0.11.5\n[v0.11.4]: https://github.com/nerves-networking/vintage_net_mobile/compare/v0.11.3...v0.11.4\n[v0.11.3]: https://github.com/nerves-networking/vintage_net_mobile/compare/v0.11.2...v0.11.3\n[v0.11.2]: https://github.com/nerves-networking/vintage_net_mobile/compare/v0.11.1...v0.11.2\n[v0.11.1]: https://github.com/nerves-networking/vintage_net_mobile/compare/v0.11.0...v0.11.1\n[v0.11.0]: https://github.com/nerves-networking/vintage_net_mobile/compare/v0.10.4...v0.11.0\n[v0.10.4]: https://github.com/nerves-networking/vintage_net_mobile/compare/v0.10.3...v0.10.4","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown"}